@@ -119,7 +119,7 @@ def build_RP():
             except IOError:
                 pass
 
-    def process_cfg(cfg, envs, check_root=None):
+    def process_cfg(cfg, envs, skip=True):
         if hasattr(cfg, "items"):
             # This method allow to delete items from a dictionary
             # while iterating over it
@@ -136,10 +136,10 @@ def build_RP():
                 if k in envs and isinstance(v, (dict, list)):
                     if k in ["IBoxLoader", "IBoxLoaderAfter"]:
                         # IBoxLoader included dict processed by
-                        # process_cfg have check_root = True
-                        kwargs = {"check_root": True}
+                        # process_cfg keep skip = True
+                        skip = True
                     else:
-                        kwargs = {}
+                        skip = False
                     try:
                         # after descending in env main key
                         # (not the one nested under region) delete key
@@ -149,22 +149,23 @@ def build_RP():
                             del cfg[k]
                     except Exception:
                         pass
-                    for result in process_cfg(v, envs, **kwargs):
+                    for result in process_cfg(v, envs, skip=skip):
                         yield result
-                if check_root:
-                    # Here i do not have yet encountered a envs key in an
-                    # IBoxLoader included dict, skip properties until i find it
+                if skip:
+                    # Here i do not have yet encountered a envs key
+                    # skip properties until i find it.
+                    # Useful for using yaml anchors before global key
                     continue
                 # for recursively descending in dict not in RP_base_keys
                 # (env/region/envrole/stacktype)
                 # (final key is the concatenation of traversed dict keys)
                 if k not in RP_base_keys and isinstance(v, dict):
                     for j, w in v.items():
-                        for result in process_cfg({f"{k}{j}": w}, envs):
+                        for result in process_cfg({f"{k}{j}": w}, envs, skip=skip):
                             yield result
         if isinstance(cfg, list):
             for n in cfg:
-                for result in process_cfg(n, envs, check_root=check_root):
+                for result in process_cfg(n, envs, skip=skip):
                     yield result
 
     def replace_not_allowed_char(s):
@@ -177,38 +178,27 @@ def build_RP():
 
         return int(key) if key.isdigit() else key
 
-    def merge_dict(base, source):
-        if isinstance(source, (str, list)) or not base:
-            return source
-        keys = dict(list(base.items()) + list(source.items())).keys()
+    def merge_dict(base, work):
+        if isinstance(work, (str, list)) or not base:
+            return work
+        keys = dict(list(base.items()) + list(work.items())).keys()
         for k in keys:
-            if isinstance(base.get(k), dict) and isinstance(source.get(k), dict):
-                base[k] = merge_dict(base[k], source[k])
-            elif k in source:
-                base[k] = source[k]
+            if k.endswith("**"):
+                # ** is used to replace existing dict instead of merging it
+                base[k.replace("**", "")] = work[k]
+            elif isinstance(base.get(k), dict) and isinstance(work.get(k), dict):
+                base[k] = merge_dict(base[k], work[k])
+            elif k.endswith("++") and isinstance(work.get(k), list):
+                # ++ is used to append elements to an existing key
+                try:
+                    base[k.replace("++", "")] += work[k]
+                except Exception:
+                    base[k.replace("++", "")] = work[k]
+            elif k in work:
+                base[k] = work[k]
         return base
 
     def merge_RP(data):
-        def _merge(base, work):
-            if isinstance(work, (str, list)) or not base:
-                return work
-            keys = dict(list(base.items()) + list(work.items())).keys()
-            for k in keys:
-                if k.endswith("**"):
-                    # ** is used to replace existing dict instead of merging it
-                    base[k.replace("**", "")] = work[k]
-                elif isinstance(base.get(k), dict) and isinstance(work.get(k), dict):
-                    base[k] = _merge(base[k], work[k])
-                elif k.endswith("++") and isinstance(work.get(k), list):
-                    # ++ is used to append elements to an existing key
-                    try:
-                        base[k.replace("++", "")] += work[k]
-                    except Exception:
-                        base[k.replace("++", "")] = work[k]
-                elif k in work:
-                    base[k] = work[k]
-            return base
-
         def _process(key, data, RP, merge=True):
             key = str(key)
 
@@ -225,7 +215,10 @@ def build_RP():
 
             if merge and isinstance(RP.get(key), dict):
                 # RP[key] already exist as a dict, try merging
-                RP[key] = _merge(RP[key], _recurse(data))
+                RP[key] = merge_dict(RP[key], _recurse(data))
+            elif isinstance(RP.get(key), str) and RP[key] == "IBOX_SKIP_FUNC":
+                # if key need to be skipped using IBOX_SKIP_FUNC avoid overwriting it
+                pass
             else:
                 RP[key] = _recurse(data)
 
@@ -260,7 +253,10 @@ def build_RP():
     def RP_to_cfg(key, prefix="", overwrite=True):
         if hasattr(key, "items"):
             for k, v in key.items():
-                key_name = f"{prefix}{k}"
+                # remove both * and + that can be present for special IBOX usage
+                key_name = f"{prefix}{k}".translate(
+                    "".maketrans({"*": None, "+": None})
+                )
                 try:
                     getattr(cfg, key_name)
                     exist = True
@@ -293,15 +289,12 @@ def build_RP():
                     )
 
                     # inject in existing structure
-                    for resource_prop, resource_prop_value in base_key_value.items():
-                        if resource_prop not in resource_key_value:
-                            resource_key_value[resource_prop] = resource_prop_value
-                        # Update existing dicts
-                        elif isinstance(resource_key_value[resource_prop], dict):
-                            # Merge base dict with the existing one
-                            resource_key_value[resource_prop] = merge_dict(
-                                copy.deepcopy(resource_prop_value),
-                                resource_key_value[resource_prop])
+                    merged = merge_dict(
+                        copy.deepcopy(base_key_value), resource_key_value
+                    )
+                    # need to do it this way to keep the "link" between existing dict keys and values
+                    for n, v in merged.items():
+                        RP[main_key][resource_key][n] = v
                 del RP[main_key][base_key]
 
     def get_RP(yaml_cfg):
@@ -429,6 +422,10 @@ def build_RP():
         pprint(LD_INCLUDED)
         print("########## INCLUDED ####### END #######")
 
+        print("########## FIXEDVALUES ######### START #####")
+        pprint(cfg.fixedvalues)
+        print("########## FIXEDVALUES ######### END #######")
+
         print("########## MAPPEDVALUES ######### START #####")
         pprint(cfg.RP_map)
         print("########## MAPPEDVALUES ######### END #######")
