@@ -15,12 +15,6 @@ from .lambdas import LambdaPermissionApiGateway
 from .iam import IAMPolicyApiGatewayPrivate
 
 
-class ApiGatewayAccount(agw.Account):
-    def __init__(self, title, **kwargs):
-        super().__init__(title, **kwargs)
-        self.CloudWatchRoleArn = get_expvalue("RoleApiGatewayCloudWatch")
-
-
 class ApiGatewayResource(agw.Resource):
     def __init__(self, title, key, stage, **kwargs):
         super().__init__(title, **kwargs)
@@ -95,13 +89,6 @@ class ApiGatewayDeployment(agw.Deployment):
         self.RestApiId = Ref("ApiGatewayRestApi")
 
 
-def AGW_Account(key):
-    # Resources
-    R_Account = ApiGatewayAccount("ApiGatewayAccount")
-
-    add_obj([R_Account])
-
-
 def AGW_DomainName(key):
     for n, v in getattr(cfg, key).items():
         if not v["IBOX_ENABLED"]:
