@@ -13,9 +13,9 @@ from .shared import (
     auto_get_props,
     get_condition,
     add_obj,
+    import_user_data,
 )
 from .cfn import *
-from .codedeploy import CD_DeploymentGroup
 from .iam import IAMInstanceProfile
 
 try:
@@ -30,11 +30,15 @@ class ASLaunchTemplateData(ec2.LaunchTemplateData):
         auto_get_props(self, "LaunchTemplateData")
         user_data = [
             "#!/bin/bash",
-            "PATH=/opt/aws/bin:$PATH",
+            "PATH=/opt/aws/bin:/usr/local/bin:$PATH",
             "export BASH_ENV=/etc/profile.d/ibox_env.sh",
             "export ENV=$BASH_ENV",
-            "yum -C list installed aws-cfn-bootstrap ||"
-            " yum install -y aws-cfn-bootstrap",
+            "yum -C list installed aws-cfn-bootstrap || yum install -y aws-cfn-bootstrap",
+            "if ( ! which cfn-init );then",
+            "  yum install -y python3-pip chkconfig",
+            "  pip3 install https://s3.amazonaws.com/cloudformation-examples/aws-cfn-bootstrap-py3-latest.tar.gz",
+            "  cp /usr/local/init/systemd/cfn-hup.service /etc/systemd/system/ && systemctl daemon-reload",
+            "fi",
             Sub("".join(UserDataApp)),
             Sub(
                 "cfn-init -v --stack ${AWS::StackName} --role ${RoleInstance}"
@@ -52,24 +56,40 @@ class ASLaunchTemplateData(ec2.LaunchTemplateData):
             "rm /var/lib/cloud/instance/sem/config_scripts_user\n",
         ]
 
+        user_data = Join("\n", user_data)
+
         try:
+            # look for external file
+            user_data = import_user_data(
+                getattr(cfg, "IBOX_ROLE_EX", getattr(cfg, "envrole"))
+            )
+        except Exception:
+            pass
+        else:
+            if "cfn-init" not in user_data:
+                cfg.use_cfn_init = False
+            user_data = Join("", user_data)
+
+        try:
+            # look for bottlerocket key
             cfg.BottleRocket
         except Exception:
-            self.UserData = Base64(Join("\n", user_data))
+            # use standard cfg
+            self.UserData = Base64(user_data)
         else:
+            # use if condition with both bottlerocket custom and standard cfg
             self.UserData = Base64(
-                Join(
-                    "\n",
-                    If(
-                        "BottleRocket",
+                If(
+                    "BottleRocket",
+                    Join(
+                        "\n",
                         [
                             get_endvalue(f"BottleRocketUserData{n}Line")
                             for n in cfg.BottleRocketUserData
-                        ]
-                        + ["\n"],
-                        user_data,
+                        ],
                     ),
-                )
+                    user_data,
+                ),
             )
 
 
@@ -586,6 +606,7 @@ def AS_ScalingPolicies(key):
 
 
 def AS_LaunchTemplate():
+    cfg.use_cfn_init = True
     InitConfigSets = ASInitConfigSets()
 
     CfmInitArgs = {}
@@ -658,14 +679,6 @@ def AS_LaunchTemplate():
 
         Tags_List.append(asg.Tag(envname, Ref(envname), True))
 
-        # resources
-        # FOR MULTIAPP CODEDEPLOY
-        if len(cfg.Apps) > 1:
-            r_DeploymentGroup = CDDeploymentGroup(f"DeploymentGroup{name}")
-            r_DeploymentGroup.setup(index=n)
-
-            add_obj(r_DeploymentGroup)
-
         # outputs
         Output_app = Output(envname)
         Output_app.Value = Ref(envname)
@@ -684,9 +697,8 @@ def AS_LaunchTemplate():
     CfmInitArgs["SETUP"] = InitConfigSetup
     CfmInitArgs["CWAGENT"] = ASInitConfigCloudWatchAgent("")
 
-    if cfg.Apps:
+    if cfg.CodeDeploy:
         CfmInitArgs["CODEDEPLOY"] = InitConfigCodeDeploy
-        CD_DeploymentGroup()
 
     if not getattr(cfg, "IBOX_LAUNCH_TEMPLATE_NO_WAIT_ELB_HEALTH", False):
         for lb in cfg.LoadBalancer:
@@ -730,32 +742,37 @@ def AS_LaunchTemplate():
     # Import role specific cfn definition
     try:
         # Do not use role but direct cfg yaml configuration (ecs + cluster)
-        cfn_envrole = cfg.IBOX_CFN_FUNC
+        cfn_envrole = f"cfn_{cfg.IBOX_ROLE_EX}"
     except Exception:
-        cfn_envrole = f"cfn_{cfg.func_envrole}"
+        cfn_envrole = f"cfn_{cfg.envrole}"
+    cfn_envrole = cfn_envrole.replace("-", "_")
     if cfn_envrole in globals():  # Ex cfn_client_portal
         CfnRole = globals()[cfn_envrole]()
         CfmInitArgs.update(CfnRole)
 
-    R_LaunchTemplate.Metadata = cfm.Metadata(
-        {
-            "CloudFormationInitVersion": If(
-                "CloudFormationInit",
-                Ref("EnvStackVersion"),
-                Ref("AWS::NoValue"),
-            )
-        },
-        cfm.Init(InitConfigSets, **CfmInitArgs),
-        cfm.Authentication(
+    if cfg.use_cfn_init:
+        R_LaunchTemplate.Metadata = cfm.Metadata(
             {
-                "CfnS3Auth": cfm.AuthenticationBlock(
-                    type="S3",
-                    buckets=[Sub(cfg.BucketNameAppRepository), Sub(cfg.BucketNameAppData)],
-                    roleName=Ref("RoleInstance"),
+                "CloudFormationInitVersion": If(
+                    "CloudFormationInit",
+                    Ref("EnvStackVersion"),
+                    Ref("AWS::NoValue"),
                 )
-            }
-        ),
-    )
+            },
+            cfm.Init(InitConfigSets, **CfmInitArgs),
+            cfm.Authentication(
+                {
+                    "CfnS3Auth": cfm.AuthenticationBlock(
+                        type="S3",
+                        buckets=[
+                            Sub(cfg.BucketNameAppRepository),
+                            Sub(cfg.BucketNameAppData),
+                        ],
+                        roleName=Ref("RoleInstance"),
+                    )
+                }
+            ),
+        )
 
     add_obj([R_LaunchTemplate, R_InstanceProfile])
 
@@ -790,37 +807,3 @@ def AS_Autoscaling(key):
     R_ASG.Tags += LaunchTemplateTags
 
     add_obj([R_ASG])
-
-
-def AS_ScheduledActioneEC2(key):
-    for n, v in getattr(cfg, key).items():
-        resname = f"{key}{n}"
-
-        r_ScheduledActions = asg.ScheduledAction(resname)
-        auto_get_props(r_ScheduledActions)
-        add_obj(r_ScheduledActions)
-
-
-def AS_ScalableTargetECS(key):
-    for n, v in getattr(cfg, key).items():
-        resname = f"{key}{n}"
-
-        # resources
-        # trick - use fixed name ScalableTarget to avoid changin too much
-        # code for now
-        r_ScalableTarget = aas.ScalableTarget("ScalableTarget")
-        auto_get_props(r_ScalableTarget, f"{key}Service")
-
-        ScheduledActions = []
-        for m, w in cfg.ScalableTargetScheduledAction.items():
-            if not w.get("IBOX_ENABLED", True):
-                continue
-            sc_name = f"ScalableTargetScheduledAction{m}"
-            r_ScheduledAction = aas.ScheduledAction(sc_name)
-            auto_get_props(r_ScheduledAction)
-            ScheduledActions.append(
-                If(f"{sc_name}Disable", Ref("AWS::NoValue"), r_ScheduledAction)
-            )
-        r_ScalableTarget.ScheduledActions = ScheduledActions
-
-        add_obj([r_ScalableTarget])
