@@ -13,6 +13,8 @@ Mappings = {}
 Resources = {}
 Outputs = {}
 
+OBJS = {}
+
 PATH_INT = os.path.join(os.path.dirname(os.path.realpath(__file__)), "cfg")
 PATH_INT = os.path.normpath(PATH_INT)
 
@@ -61,6 +63,15 @@ AZones = {
 
 AZoneNames = ["A", "B", "C", "D", "E", "F"]
 
+VPC_DEFAULT_CIDR_BLOCK = "10.80.0.0/16"
+VPC_DEFAULT_CIDR_BLOCK_PREFIX = ".".join(VPC_DEFAULT_CIDR_BLOCK.split(".")[0:2])
+VPC_DEFAULT_SUBNETS_CIDR_BLOCK_PRIVATE = [
+    f"{VPC_DEFAULT_CIDR_BLOCK_PREFIX}.{i * 16}.0/20" for i in range(AZones["MAX"])
+]
+VPC_DEFAULT_SUBNETS_CIDR_BLOCK_PUBLIC = [
+    f"{VPC_DEFAULT_CIDR_BLOCK_PREFIX}.{i + 200}.0/24" for i in range(AZones["MAX"])
+]
+
 PARAMETERS_SKIP_OVERRIDE_CONDITION = (
     "Env",
     "UpdateMode",
@@ -243,85 +254,150 @@ CFG_TO_FUNC = {
     "Parameter": {"module": "cloudformation", "func": "CFM_Parameters"},
     "Condition": {"module": "cloudformation", "func": "CFM_Conditions"},
     "Mapping": {"module": "cloudformation", "func": "CFM_Mappings"},
-    # SecurityGroups need to stay here because it populate a cfg value
-    # [cfg.SecurityGroupsImport] used later by other keys/modules
-    "SecurityGroups": {"module": "securitygroup", "func": "SG_SecurityGroups"},
-    "AutoScalingGroup": {"module": "autoscaling", "func": "AS_Autoscaling"},
-    "ScheduledAction": {"module": "joker", "func": ("autoscaling", "ScheduledAction")},
-    "ScalableTarget": {"module": "autoscaling", "func": "AS_ScalableTarget"},
-    "AutoScalingScalingPolicy": {"module": "autoscaling", "func": "AS_ScalingPolicies"},
-    "ApplicationAutoScalingScalingPolicy": {
-        "module": "autoscaling",
-        "func": "AS_ScalingPolicies",
-    },
-    "Bucket": {"module": "s3", "func": "S3_Buckets"},
-    "Certificate": {"module": "joker", "func": ("certificatemanager", "Certificate")},
-    "CodeDeployApp": {"module": "codedeploy", "func": "CD_Applications"},
-    "Repository": {"module": "ecr", "func": "ECR_Repositories"},
-    "ECSCluster": {"module": "joker", "func": ("ecs", "Cluster")},
-    "ECSCapacityProvider": {"module": "joker", "func": ("ecs", "CapacityProvider")},
-    "ECSClusterCapacityProviderAssociations": {
+    "Alarm": {
         "module": "joker",
-        "func": ("ecs", "ClusterCapacityProviderAssociations"),
+        "func": ("cloudwatch", "Alarm"),
+        "dep": ["LoadBalancer"],
     },
-    "Service": {"module": "ecs", "func": "ECS_Service"},
-    "ApiGatewayAccount": {"module": "apigateway", "func": "AGW_Account"},
-    "ApiGatewayDomainName": {"module": "apigateway", "func": "AGW_DomainName"},
-    "ApiGatewayRestApi": {"module": "apigateway", "func": "AGW_RestApi"},
+    "ApiGatewayAccount": {"module": "joker", "func": ("apigateway", "Account")},
+    "ApiGatewayApiKey": {"module": "apigateway", "func": "AGW_ApiKeys"},
     "ApiGatewayBasePathMapping": {
         "module": "joker",
         "func": ("apigateway", "BasePathMapping"),
     },
+    "ApiGatewayDomainName": {"module": "apigateway", "func": "AGW_DomainName"},
+    "ApiGatewayRestApi": {"module": "apigateway", "func": "AGW_RestApi"},
     "ApiGatewayStage": {"module": "apigateway", "func": "AGW_Stages"},
     "ApiGatewayUsagePlan": {"module": "apigateway", "func": "AGW_UsagePlans"},
-    "ApiGatewayApiKey": {"module": "apigateway", "func": "AGW_ApiKeys"},
-    "LogGroupName": {"module": "logs", "func": "LGS_LogGroup"},
-    "TaskDefinition": {"module": "ecs", "func": "ECS_TaskDefinition"},
-    "EFSFileSystem": {"module": "efs", "func": "EFS_FileStorage"},
-    "EFSAccessPoint": {"module": "joker", "func": ("efs", "AccessPoint")},
-    "CacheSubnetGroup": {"module": "elasticache", "func": "CCH_SubnetGroups"},
-    "CacheCluster": {"module": "elasticache", "func": "CCH_Cache"},
-    "EventsRule": {"module": "events", "func": "EVE_EventRules"},
-    "Role": {"module": "iam", "func": "IAM_Roles"},
-    "IAMPolicy": {"module": "iam", "func": "IAM_Policies"},
-    "IAMUser": {"module": "iam", "func": "IAM_Users"},
-    "IAMGroup": {"module": "iam", "func": "IAM_Groups"},
-    "IAMUserToGroupAddition": {"module": "iam", "func": "IAM_UserToGroupAdditions"},
-    "KMSKey": {"module": "kms", "func": "KMS_Keys"},
-    "Lambda": {"module": "lambdas", "func": "LBD_Lambdas"},
-    "LambdaLayerVersion": {"module": "lambdas", "func": "LBD_LayerVersions"},
-    "LambdaPermission": {"module": "joker", "func": ("awslambda", "Permission")},
-    "LambdaEventSourceMapping": {
-        "module": "joker",
-        "func": ("awslambda", "EventSourceMapping"),
+    "ApplicationAutoScalingScalingPolicy": {
+        "module": "autoscaling",
+        "func": "AS_ScalingPolicies",
     },
-    "LambdaEventInvokeConfig": {
-        "module": "joker",
-        "func": ("awslambda", "EventInvokeConfig"),
+    "Apps": {"module": "joker", "func": ("codedeploy", "DeploymentGroup")},
+    "ASGLifecycleHook": {"module": "joker", "func": ("autoscaling", "LifecycleHook")},
+    "AutoScalingGroup": {
+        "module": "autoscaling",
+        "func": "AS_Autoscaling",
+        "dep": ["SecurityGroups"],
     },
-    "LoadBalancer": {
-        "module": "loadbalancing",
-        "func": "LB_ElasticLoadBalancing",
-    },
-    "Alarm": {"module": "joker", "func": ("cloudwatch", "Alarm")},
-    "CloudFrontDistribution": {"module": "cloudfront", "func": "CF_CloudFront"},
+    "AutoScalingScalingPolicy": {"module": "autoscaling", "func": "AS_ScalingPolicies"},
+    "Bucket": {"module": "s3", "func": "S3_Buckets"},
+    "Certificate": {"module": "joker", "func": ("certificatemanager", "Certificate")},
+    "CacheSubnetGroup": {"module": "joker", "func": ("elasticache", "SubnetGroup")},
     "CloudFrontCachePolicy": {"module": "joker", "func": ("cloudfront", "CachePolicy")},
-    "CloudFrontOriginRequestPolicy": {
-        "module": "joker",
-        "func": ("cloudfront", "OriginRequestPolicy"),
+    "CloudFrontDistribution": {
+        "module": "cloudfront",
+        "func": "CF_CloudFront",
+        "dep": ["LoadBalancer"],
     },
     "CloudFrontOriginAccessIdentity": {
         "module": "joker",
         "func": ("cloudfront", "CloudFrontOriginAccessIdentity"),
     },
-    "SNSSubscription": {"module": "sns", "func": "SNS_Subscriptions"},
-    "SNSTopic": {"module": "sns", "func": "SNS_Topics"},
-    "SQSQueue": {"module": "joker", "func": ("sqs", "Queue")},
-    "ASGLifecycleHook": {"module": "joker", "func": ("autoscaling", "LifecycleHook")},
+    "CloudFrontOriginRequestPolicy": {
+        "module": "joker",
+        "func": ("cloudfront", "OriginRequestPolicy"),
+    },
+    "CodeDeployApp": {"module": "joker", "func": ("codedeploy", "Application")},
     "DBInstance": {"module": "rds", "func": "RDS_DB"},
-    "DBSubnetGroup": {"module": "rds", "func": "RDS_SubnetGroups"},
+    "DBSubnetGroup": {"module": "joker", "func": ("rds", "DBSubnetGroup")},
+    "DynamoDBTable": {"module": "joker", "func": ("dynamodb", "Table")},
+    "EC2EIP": {"module": "joker", "func": ("ec2", "EIP")},
+    "EC2InternetGateway": {"module": "joker", "func": ("ec2", "InternetGateway")},
+    "EC2NatGateway": {"module": "joker", "func": ("ec2", "NatGateway")},
+    "EC2Route": {"module": "joker", "func": ("ec2", "Route")},
+    "EC2RouteTable": {"module": "joker", "func": ("ec2", "RouteTable")},
+    "EC2Subnet": {"module": "ec2", "func": "EC2_Subnet"},
+    "EC2VPC": {"module": "joker", "func": ("ec2", "VPC")},
+    "EC2VPCEndpoint": {"module": "joker", "func": ("ec2", "VPCEndpoint")},
+    "EC2VPCGatewayAttachment": {
+        "module": "joker",
+        "func": ("ec2", "VPCGatewayAttachment"),
+    },
+    "EC2VPCPeeringConnection": {
+        "module": "joker",
+        "func": ("ec2", "VPCPeeringConnection"),
+    },
+    "ECSCapacityProvider": {"module": "joker", "func": ("ecs", "CapacityProvider")},
+    "ECSCluster": {"module": "joker", "func": ("ecs", "Cluster")},
+    "ECSClusterCapacityProviderAssociations": {
+        "module": "joker",
+        "func": ("ecs", "ClusterCapacityProviderAssociations"),
+    },
+    "EFSAccessPoint": {"module": "joker", "func": ("efs", "AccessPoint")},
+    "EFSFileSystem": {"module": "efs", "func": "EFS_FileStorage"},
+    "ElastiCacheCacheCluster": {
+        "module": "joker",
+        "func": ("elasticache", "CacheCluster"),
+    },
+    "ElastiCacheReplicationGroup": {
+        "module": "joker",
+        "func": ("elasticache", "ReplicationGroup"),
+    },
+    "EventsRule": {
+        "module": "events",
+        "func": "EVE_EventRules",
+        "dep": ["SecurityGroups"],
+    },
     "HostedZone": {"module": "route53", "func": "R53_HostedZones"},
-    "R53RecordSet": {"module": "route53", "func": "R53_RecordSets"},
+    "IAMGroup": {"module": "iam", "func": "IAM_Groups"},
+    "IAMPolicy": {"module": "iam", "func": "IAM_Policies"},
+    "IAMUser": {"module": "iam", "func": "IAM_Users"},
+    "IAMUserToGroupAddition": {"module": "iam", "func": "IAM_UserToGroupAdditions"},
+    "KMSAlias": {"module": "joker", "func": ("kms", "Alias")},
+    "KMSKey": {"module": "joker", "func": ("kms", "Key")},
+    "Lambda": {"module": "lambdas", "func": "LBD_Lambdas"},
+    "LambdaEventInvokeConfig": {
+        "module": "joker",
+        "func": ("awslambda", "EventInvokeConfig"),
+    },
+    "LambdaEventSourceMapping": {
+        "module": "joker",
+        "func": ("awslambda", "EventSourceMapping"),
+    },
+    "LambdaFunctionAssociation": {
+        "module": "joker",
+        "func": ("cloudfront", "LambdaFunctionAssociation"),
+        "dep": ["CloudFrontDistribution"],
+    },
+    "LambdaLayerVersion": {"module": "lambdas", "func": "LBD_LayerVersions"},
+    "LambdaPermission": {"module": "joker", "func": ("awslambda", "Permission")},
+    "LoadBalancer": {
+        "module": "loadbalancing",
+        "func": "LB_ElasticLoadBalancing",
+    },
+    "LogsLogGroup": {"module": "joker", "func": ("logs", "LogGroup")},
+    "ScheduledAction": {"module": "joker", "func": ("autoscaling", "ScheduledAction")},
+    "ScalableTarget": {
+        "module": "joker",
+        "func": ("applicationautoscaling", "ScalableTarget"),
+    },
+    "R53RecordSet": {"module": "joker", "func": ("route53", "RecordSetType")},
+    "Repository": {"module": "ecr", "func": "ECR_Repositories"},
+    "Role": {"module": "iam", "func": "IAM_Roles"},
+    "SecurityGroup": {"module": "securitygroup", "func": "SG_SecurityGroup"},
+    "SecurityGroupIngress": {
+        "module": "securitygroup",
+        "func": "SG_SecurityGroupIngresses",
+    },
+    "SecurityGroups": {"module": "securitygroup", "func": "SG_SecurityGroups"},
+    "Service": {
+        "module": "ecs",
+        "func": "ECS_Service",
+        "dep": ["SecurityGroups"],
+    },
+    "ServiceDiscoveryPublicDnsNamespace": {
+        "module": "joker",
+        "func": ("servicediscovery", "PublicDnsNamespace"),
+    },
+    "ServiceDiscoveryService": {
+        "module": "joker",
+        "func": ("servicediscovery", "Service"),
+    },
+    "SQSQueue": {"module": "joker", "func": ("sqs", "Queue")},
+    "SNSSubscription": {"module": "sns", "func": "SNS_Subscriptions"},
+    "SNSTopic": {"module": "joker", "func": ("sns", "Topic")},
+    "TaskDefinition": {"module": "ecs", "func": "ECS_TaskDefinition"},
     "WafByteMatchSet": {
         "module": "waf",
         "func": ["WAF_GlobalByteMatchSets", "WAF_RegionalByteMatchSets"],
@@ -332,30 +408,24 @@ CFG_TO_FUNC = {
         "module": "waf",
         "func": ["WAF_GlobalWebAcls", "WAF_RegionalWebAcls"],
     },
-    "ServiceDiscoveryPublicDnsNamespace": {
+    "WAFv2IPSet": {
         "module": "joker",
-        "func": ("servicediscovery", "PublicDnsNamespace"),
+        "func": ("wafv2", "IPSet"),
     },
-    "ServiceDiscoveryService": {
+    "WAFv2WebACL": {
         "module": "joker",
-        "func": ("servicediscovery", "Service"),
-    },
-    "VPCEndpoint": {"module": "vpc", "func": "VPC_Endpoint"},
-    "SecurityGroup": {"module": "securitygroup", "func": "SG_SecurityGroup"},
-    "SecurityGroupIngress": {
-        "module": "securitygroup",
-        "func": "SG_SecurityGroupIngresses",
-    },
-    "VPC": {"module": "vpc", "func": "VPC_VPC"},
-    "CCRLightHouse": {
-        "module": "cloudformation",
-        "func": "CFM_CustomResourceLightHouse",
+        "func": ("wafv2", "WebACL"),
     },
+    # CloudformationCustomResource begin here
     "CCRFargateSpot": {
         "module": "cloudformation",
         "func": "CFM_CustomResourceFargateSpot",
     },
-    # ReplicateRegions need to stay here
+    "CCRLightHouse": {
+        "module": "cloudformation",
+        "func": "CFM_CustomResourceLightHouse",
+    },
+    # ReplicateRegions need to be the last one
     "CCRReplicateRegions": {
         "module": "cloudformation",
         "func": "CFM_CustomResourceReplicator",
