@@ -4,6 +4,14 @@ import troposphere.policies as pol
 
 from .common import *
 
+IBOX_SPECIAL_KEYS = (
+    "IBOX_RESNAME",
+    "IBOX_MAPNAME",
+    "IBOX_REMAPNAME",
+    "IBOX_INDEXNAME",
+    "IBOX_PROPNAME",
+)
+
 
 # S - PARAMETERS #
 class SSMParameter(ssm.Parameter):
@@ -89,7 +97,21 @@ def add_obj(obj):
     elif isinstance(obj, Output):
         cfg.Outputs[obj.title] = obj
     else:
-        cfg.Resources[obj.title] = obj
+        title = obj.title
+        if hasattr(obj, "resource_type"):
+            # if AWSObject add obj to resources
+            add_to = "Resources"
+        else:
+            # otherway add it to OBJS, usefull to include it later
+            add_to = "OBJS"
+            if hasattr(obj, "Condition"):
+                # Condition is not supported on Resource properties, but use it
+                # to wrap obj in an If Condition - needed for LambdaFunctionAssociation
+                cond_name = obj.Condition
+                del obj.properties["Condition"]
+                obj = If(cond_name, obj, Ref("AWS::NoValue"))
+
+        getattr(cfg, add_to)[title] = obj
 
 
 def add_objoutput(res):
@@ -292,6 +314,10 @@ def get_resvalue(resname, propname):
 def get_dictvalue(key):
     if isinstance(key, list):
         value = [get_dictvalue(k) for k in key]
+    elif isinstance(key, dict) and "IBOX_LIST" in key:
+        # Usefull for KMS policy and other generic dict properties
+        del key["IBOX_LIST"]
+        value = [{i: get_dictvalue(k) for i, k in key.items()}]
     elif isinstance(key, dict):
         value = {i: get_dictvalue(k) for i, k in key.items()}
     else:
@@ -387,6 +413,46 @@ def get_condition(
     return condition
 
 
+def import_user_data(name):
+    TK_IN_UDATA = "IBOX_CODE_IN_USER_DATA"
+
+    udata_file = os.path.join(os.getcwd(), f"lib/user-data/{name}.sh")
+    if not os.path.exists(udata_file):
+        parent_dir_name = os.path.dirname(os.path.realpath(__file__))
+        udata_file = os.path.join(parent_dir_name, f"user-data/{name}.sh")
+
+    try:
+        with open(udata_file, "r") as f:
+            fdata = f.read()
+            code = fdata
+            code_lines = code.splitlines(keepends=True)
+
+            file_lines = []
+            # parse lambda code for Token IBOX CODE
+            for x in code_lines:
+                if x.startswith(cfg.EVAL_FUNCTIONS_IN_CFG):
+                    value = eval(x)
+                elif x.startswith(TK_IN_UDATA):
+                    value = '"'
+                elif TK_IN_UDATA in x:
+                    # parse minified code
+                    tks = x.split(TK_IN_UDATA)
+                    file_lines.extend([f"{tks[0]}", eval(tks[1]), tks[2]])
+                    continue
+                else:
+                    value = "".join(x)
+
+                file_lines.append(value)
+
+            return file_lines
+
+    except IOError:
+        raise
+    except Exception as e:
+        logging.error(f"Error importing user-data: {e}")
+        exit(1)
+
+
 def import_lambda(name):
     TK_IN_LBD = "IBOX_CODE_IN_LAMBDA"
     parent_dir_name = os.path.dirname(os.path.realpath(__file__))
@@ -394,17 +460,25 @@ def import_lambda(name):
     if not os.path.exists(lambda_file):
         lambda_file = os.path.join(parent_dir_name, "lambdas/%s.code" % name)
     try:
+        lambda_file_trunk = os.path.join(*PurePath(lambda_file).parts[-3:])
         with open(lambda_file, "r") as f:
             fdata = f.read()
 
             try:
                 # try to minify using python_minifier
                 code = python_minifier.minify(fdata)
+                if len(code) > 4096:
+                    logging.warning(
+                        f"{lambda_file_trunk} > 4096, trying to minify it using a more aggressive option [rename_globals=True]"
+                    )
+                    code = python_minifier.minify(
+                        fdata, rename_globals=True, preserve_globals=["lambda_handler"]
+                    )
             except Exception:
                 code = fdata
 
             if len(code) > 4096:
-                logging.warning(f"Inline lambda {lambda_file} > 4096")
+                logging.warning(f"Inline lambda {lambda_file_trunk} > 4096")
 
             code_lines = code.splitlines(keepends=True)
 
@@ -430,17 +504,20 @@ def import_lambda(name):
     except IOError:
         logging.warning(f"Lambda code {name} not found")
         exit(1)
+    except Exception as e:
+        logging.error(e)
 
 
 def auto_get_props(
     obj, mapname=None, key=None, rootdict=None, indexname="", remapname=None
 ):
     # IBOX_RESNAME can be used in yaml and resolved inside get_endvalue
-    global IBOX_RESNAME, IBOX_MAPNAME, IBOX_INDEXNAME, IBOX_REMAPNAME
+    global IBOX_RESNAME, IBOX_MAPNAME, IBOX_INDEXNAME, IBOX_REMAPNAME, IBOX_PROPNAME
     IBOX_RESNAME = obj.title
     IBOX_MAPNAME = mapname
     IBOX_REMAPNAME = remapname
     IBOX_INDEXNAME = indexname
+    IBOX_PROPNAME = ""
 
     # create a dict where i will put all property with a flat hierarchy
     # with the name equals to the mapname and the relative value.
@@ -449,8 +526,8 @@ def auto_get_props(
     IBOX_PROPS = {"MAP": {}}
 
     def _iboxif(if_wrapper, mapname, value):
-        condname = if_wrapper[0].replace("IBOX_MAPNAME_", mapname)
-        condname = condname.replace("_", IBOX_RESNAME)
+        condname = if_wrapper[0].replace("IBOX_MAPNAME", mapname)
+        condname = parse_ibox_key(condname)
         condvalues = []
         for i in if_wrapper[1:3]:
             if isinstance(i, str) and i.startswith(cfg.EVAL_FUNCTIONS_IN_CFG):
@@ -469,6 +546,7 @@ def auto_get_props(
     def _get_obj(obj, key, obj_propname, mapname):
         props = obj.props
         mapname_obj = f"{mapname}{obj_propname}"
+        global IBOX_PROPNAME
 
         def _get_obj_tags():
             prop_list = []
@@ -533,27 +611,51 @@ def auto_get_props(
         ):
             prop_list = []
             prop_class = props[obj_propname][0][0]
-            for o, v in key[obj_propname].items():
-                if o == "IBOX_IF":
-                    # element named IBOX_IF must no be parsed
-                    # is needed for wrapping whole returned obj in _populate
-                    continue
-                name_o = str(o)
-                mapname_o = f"{mapname_obj}{name_o}"
-                prop_obj = prop_class()
 
-                _populate(prop_obj, key=v, mapname=mapname_o)
-
-                # trick to wrapper single obj in If Condition
-                try:
-                    if_wrapper = v["IBOX_IF"]
-                except Exception:
+            # for sub obj defined elsewhere
+            ibox_sub_obj = key[obj_propname].get("IBOX_SUB_OBJ")
+            if ibox_sub_obj:
+                for o, v in getattr(cfg, ibox_sub_obj).items():
+                    obj_name = f"{ibox_sub_obj}{o}"
+                    prop_obj = prop_class(obj_name)
+                    auto_get_props(prop_obj)
+                    if_wrapper = v.get("IBOX_IF")
+                    if if_wrapper:
+                        prop_obj = _iboxif(if_wrapper, obj_propname, prop_obj)
                     prop_list.append(prop_obj)
-                else:
-                    prop_list.append(_iboxif(if_wrapper, mapname, prop_obj))
+            else:
+                for o, v in key[obj_propname].items():
+                    # for a list of properties set IBOX_PROPNAME to the name of property
+                    IBOX_PROPNAME = o
+
+                    if o == "IBOX_IF":
+                        # element named IBOX_IF must no be parsed
+                        # is needed for wrapping whole returned obj in _populate
+                        continue
+                    name_o = str(o)
+                    mapname_o = f"{mapname_obj}{name_o}"
+                    prop_obj = prop_class()
+
+                    _populate(prop_obj, key=v, mapname=mapname_o)
+
+                    # trick to wrapper single obj in If Condition
+                    try:
+                        if_wrapper = v["IBOX_IF"]
+                    except Exception:
+                        prop_list.append(prop_obj)
+                    else:
+                        prop_list.append(_iboxif(if_wrapper, mapname, prop_obj))
 
             return prop_list
 
+        # Pure dict as KSM Key KeyPolicy
+        elif (
+            isinstance(prop_class, tuple)
+            and isinstance(prop_class[0], type)
+            and prop_class[0].__name__ == "dict"
+        ):
+            return get_dictvalue(key[obj_propname])
+
     def _populate(obj, key=None, mapname=None, rootdict=None):
         if not mapname:
             mapname = obj.title
@@ -566,25 +668,22 @@ def auto_get_props(
         def _try_PCO_in_obj(key):
             def _parameter(k):
                 for n, v in k.items():
-                    n = n.replace("{IBOX_INDEXNAME}", IBOX_INDEXNAME)
-                    n = n.replace("_", IBOX_RESNAME)
+                    n = parse_ibox_key(n)
                     parameter = Parameter(n)
                     _populate(parameter, rootdict=v)
                     add_obj(parameter)
 
             def _condition(k):
                 for n, v in k.items():
-                    if IBOX_MAPNAME:
-                        n = n.replace("IBOX_MAPNAME", IBOX_MAPNAME)
-                    n = n.replace("{IBOX_INDEXNAME}", IBOX_INDEXNAME)
-                    n = n.replace("_", IBOX_RESNAME)
+                    n = parse_ibox_key(n)
                     condition = {n: eval(v)}
                     add_obj(condition)
 
             def _output(k):
                 for n, v in k.items():
-                    n = n.replace("{IBOX_INDEXNAME}", IBOX_INDEXNAME)
-                    n = n.replace("_", IBOX_RESNAME)
+                    n = parse_ibox_key(n)
+                    if not eval(v.get("IBOX_CODE_IF", "True")):
+                        continue
                     output = Output(n)
                     _populate(output, rootdict=v)
                     # alter troposphere obj and add IBOX property
@@ -665,10 +764,10 @@ def auto_get_props(
                     # key value is a dict, get populated object
                     value = _get_obj(obj, key, propname, mapname)
                 elif isinstance(key_value, str) and key_value.startswith(
-                    "IBOX_RESNAME"
+                    IBOX_SPECIAL_KEYS
                 ):
-                    # replace IBOX_RESNAME string with IBOX_RESNAME value
-                    value = key_value.replace("IBOX_RESNAME", IBOX_RESNAME)
+                    # parse value for IBOX special keys
+                    value = parse_ibox_key(key_value)
                 elif rootdict:
                     # rootdict is needed by lib/efs.py EFS_FileStorage SGIExtra
                     # where is passed as a dictionary to parse for parameters
@@ -723,7 +822,7 @@ def auto_get_props(
 
         # title override
         try:
-            obj.title = key["IBOX_TITLE"]
+            obj.title = parse_ibox_key(key["IBOX_TITLE"])
         except Exception:
             pass
 
@@ -794,6 +893,16 @@ def clf_compute_order(pattern):
     return base_ord
 
 
+def parse_ibox_key(value):
+    for key in IBOX_SPECIAL_KEYS:
+        if key in value:
+            value = value.replace(key, globals().get(key, ""))
+    value = value.replace("_", IBOX_RESNAME)
+    value = value.replace(".", "")
+
+    return value
+
+
 def camel_to_snake(data):
     out = ""
     skip_next = False
